RequestsThrottler is written and maintained by Lou Marvin Caraig and is powered by Requests:

Development Lead
````````````````

- Lou Marvin Caraig <loumarvincaraig@gmail.com>


Requests
````````

- Kenneth Reitz <me@kennethreitz.com>
